@@ -6,7 +6,7 @@
     'name_de_DE': 'Verkauf Lieferposten Kosten',
     'name_es_ES': 'Costo del método de envio',
     'name_fr_FR': "Coût d'expédition de vente",
-    'version': '2.0.2',
+    'version' : '2.2.0',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -23,15 +23,19 @@
         'sale',
         'currency',
         'account_invoice',
-        'stock',
     ],
     'xml' : [
         'sale.xml',
         'stock.xml',
     ],
     'translation': [
-        'de_DE.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_ES.po',
+        'locale/es_CO.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
